﻿using System;
using System.Collections;
using System.Linq;
using Microsoft.Win32;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.Spreadsheet.FormatProviders.OpenXml.Xlsx;
using Telerik.Windows.Documents.Spreadsheet.Model;
using Telerik.Windows.Examples;

namespace WpfApplication1
{
    public class MyModel : ViewModelBase
    {
        public MyModel()
        {
            this.ExportCommand = new MyCommand(this.Export);
        }

        private IEnumerable data;
        public IEnumerable Data
        {
            get
            {
                if (this.data == null)
                {
                    this.data = new MyBusinessObjects().GetData(1000);
                }

                return data;
            }
        }

        private MyCommand exportCommand;
        public MyCommand ExportCommand
        {
            get
            {
                return this.exportCommand;
            }
            set
            {
                if (this.exportCommand != value)
                {
                    this.exportCommand = value;
                    this.OnPropertyChanged("ExportCommand");
                }
            }
        }

        public void Export(object parameter)
        {
            var grid = parameter as RadGridView;
            if (grid != null)
            {
                var dialog = new SaveFileDialog();

                dialog.DefaultExt = "*.xlsx";
                dialog.Filter = "Excel Workbook (*.xlsx)|*.xlsx";

                if (dialog.ShowDialog() == true)
                {
                    var workbook = CreateWorkBook(grid);

                    if (workbook != null)
                    {
                        var provider = new XlsxFormatProvider();
                        using (var output = dialog.OpenFile())
                        {
                            provider.Export(workbook, output);
                        }
                    }
                }
            }
        }

        private static Workbook CreateWorkBook(RadGridView grid)
        {
            var workbook = new Workbook();
            var worksheet = workbook.Worksheets.Add();

            for (var i = 0; i < grid.Items.Count; i++)
            {
                for (var j = 0; j < grid.Columns.Count; j++)
                {
                    var boundColumn = grid.Columns[j] as GridViewBoundColumnBase;
                    if (boundColumn != null)
                    {
                        worksheet.Cells[i, j].SetValue(string.Format("{0}", boundColumn.GetValueForItem(grid.Items[i])));
                    }
                }
            }

            return workbook;
        }
    }
}
